[![New release](https://img.shields.io/github/v/release/ConvexRegression/cvxreg?display_name=tag&label=Lastest&color=%234B78E6)](https://github.com/ConvexRegression/cvxreg/releases)
[![Documentation Status](https://readthedocs.org/projects/cvxreg/badge/?version=latest)](https://cvxreg.readthedocs.io/en/latest/?badge=latest)
[![PyPI downloads](https://img.shields.io/pypi/dm/cvxreg.svg?maxAge=21600)](https://pypistats.org/packages/cvxreg)

**cvxreg** is a Python package for machine learing with convex regression models built on [`pyStoNED`](https://github.com/ds2010/pyStoNED). 

The core aims of this package are:
* make convex regression models "easy to call" from python,
* interface with [`pyStoNED`](https://github.com/ds2010/pyStoNED),
* focus on a "machine learning" perspective, i.e.: predictive task, hyper-parameters should be obtained by a data-driven method such as cross-validation.

## Installation

The [`cvxreg`](https://pypi.org/project/pycreg) package is now avaiable on PyPI and the latest development version can be installed from the Github repository [`ConvexRegression`](https://github.com/ConvexRegression/cvxreg). Please feel free to download and test it. We welcome any bug reports and feedback.

#### PyPI 

    pip install cvxreg

